==> papilo-2.2.1-1-aarch64.pkg.tar.xz: usr/include/papilo/Config.hpp <==
/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/*                                                                           */
/*               This file is part of the program and library                */
/*    PaPILO --- Parallel Presolve for Integer and Linear Optimization       */
/*                                                                           */
/* Copyright (C) 2020-2024 Zuse Institute Berlin (ZIB)                       */
/*                                                                           */
/* This program is free software: you can redistribute it and/or modify      */
/* it under the terms of the GNU Lesser General Public License as published  */
/* by the Free Software Foundation, either version 3 of the License, or      */
/* (at your option) any later version.                                       */
/*                                                                           */
/* This program is distributed in the hope that it will be useful,           */
/* but WITHOUT ANY WARRANTY; without even the implied warranty of            */
/* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             */
/* GNU Lesser General Public License for more details.                       */
/*                                                                           */
/* You should have received a copy of the GNU Lesser General Public License  */
/* along with this program.  If not, see <https://www.gnu.org/licenses/>.    */
/*                                                                           */
/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

#ifndef _PAPILO_CONFIG_HPP_
#define _PAPILO_CONFIG_HPP_

#ifndef PAPILO_NO_CMAKE_CONFIG

#include "papilo/CMakeConfig.hpp"

#else

#define PAPILO_VERSION_MAJOR 2
#define PAPILO_VERSION_MINOR 2
#define PAPILO_VERSION_PATCH 1
#define PAPILO_VERSION_TWEAK 0

#undef PAPILO_GITHASH_AVAILABLE
#undef PAPILO_GITHASH

#endif

#endif

==> papilo-2.4.2-2-aarch64.pkg.tar.xz: usr/include/papilo/Config.hpp <==
/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/*                                                                           */
/*               This file is part of the program and library                */
/*    PaPILO --- Parallel Presolve for Integer and Linear Optimization       */
/*                                                                           */
/* Copyright (C) 2020-2025 Zuse Institute Berlin (ZIB)                       */
/*                                                                           */
/* This program is free software: you can redistribute it and/or modify      */
/* it under the terms of the GNU Lesser General Public License as published  */
/* by the Free Software Foundation, either version 3 of the License, or      */
/* (at your option) any later version.                                       */
/*                                                                           */
/* This program is distributed in the hope that it will be useful,           */
/* but WITHOUT ANY WARRANTY; without even the implied warranty of            */
/* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             */
/* GNU Lesser General Public License for more details.                       */
/*                                                                           */
/* You should have received a copy of the GNU Lesser General Public License  */
/* along with this program.  If not, see <https://www.gnu.org/licenses/>.    */
/*                                                                           */
/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

#ifndef _PAPILO_CONFIG_HPP_
#define _PAPILO_CONFIG_HPP_

#ifndef PAPILO_NO_CMAKE_CONFIG

#include "papilo/CMakeConfig.hpp"

#else

#define PAPILO_VERSION_MAJOR 2
#define PAPILO_VERSION_MINOR 4
#define PAPILO_VERSION_PATCH 2
#define PAPILO_VERSION_TWEAK 0

#define PAPILO_API_VERSION 3

#undef PAPILO_GITHASH_AVAILABLE
#undef PAPILO_GITHASH

#endif

#endif
